@@ -31,7 +31,7 @@ L<Anansi::ObjectManager>.
 =cut
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Anansi::ObjectManager;
 
@@ -45,9 +45,7 @@ use Anansi::ObjectManager;
 
 =over 4
 
-=item self
-
-( I<Blessed Hash>, I<Required> )
+=item self I<(Blessed Hash, Required)>
 
 An object of this namespace.
 
@@ -76,9 +74,7 @@ sub DESTROY {
 
 =over 4
 
-=item self
-
-( I<Blessed Hash>, I<Required> )
+=item self I<(Blessed Hash, Required)>
 
 An object of this namespace.
 
@@ -110,21 +106,15 @@ sub finalise {
 
 =over 4
 
-=item self
-
-( I<Blessed Hash>, I<Required> )
+=item self I<(Blessed Hash, Required)>
 
 An object of this namespace.
 
-=item caller
-
-( I<Array>, I<Required> )
+=item caller I<(Array, Required)>
 
 An array containing the I<package>, I<file name> and I<line number> of the caller.
 
-=item parameter
-
-( I<String>, I<Required> )
+=item parameter I<(String, Required)>
 
 A string containing the name to import.
 
@@ -151,15 +141,11 @@ sub implicate {
 
 =over 4
 
-=item self
-
-( I<Blessed Hash>, I<Required> )
+=item self I<(Blessed Hash, Required)>
 
 An object of this namespace.
 
-=item parameters
-
-( I<Array>, I<Optional> )
+=item parameters I<(Array, Optional)>
 
 An array containing all of the names to import.
 
@@ -185,15 +171,11 @@ sub import {
 
 =over 4
 
-=item self
-
-( I<Blessed Hash>, I<Required> )
+=item self I<(Blessed Hash, Required)>
 
 An object of this namespace.
 
-=item parameters
-
-( I<Hash> )
+=item parameters I<(Hash)>
 
 Named parameters that were supplied to the I<new> method.
 
@@ -220,21 +202,11 @@ sub initialise {
 
 =over 4
 
-=item class
+=item class I<(Blessed Hash B<or> String, Required)>
 
-( I<Required> )
+Either an object or a string of this namespace.
 
-( I<Blessed Hash> )
-
-An object of this namespace.
-
-( I<String> )
-
-A string of the namespace.
-
-=item parameters
-
-( I<Hash>, I<Optional> )
+=item parameters I<(Hash, Optional)>
 
 Named parameters.
 
@@ -268,15 +240,11 @@ sub new {
 
 =over 4
 
-=item self
-
-( I<Blessed Hash>, I<Required> )
+=item self I<(Blessed Hash, Required)>
 
 An object of this namespace.
 
-=item parameters
-
-( I<Hash>, I<Optional> )
+=item parameters I<(Hash, Optional)>
 
 Named parameters.
 
@@ -299,15 +267,11 @@ sub old {
 
 =over 4
 
-=item self
-
-( I<Blessed Hash>, I<Required> )
+=item self I<(Blessed Hash, Required)>
 
 An object of this namespace.
 
-=item parameters
-
-( I<Array>, I<Optional> )
+=item parameters I<(Array, Optional)>
 
 An array of strings containing the names of blessed objects currently in use by
 this object.
@@ -346,15 +310,11 @@ sub used {
 
 =over 4
 
-=item self
-
-( I<Blessed Hash>, I<Required> )
+=item self I<(Blessed Hash, Required)>
 
 An object of this namespace.
 
-=item parameters
-
-( I<Hash>, I<Optional> )
+=item parameters I<(Hash, Optional)>
 
 A hash containing keys that represent the name to associate with the string
 namespace or object within the associated values.
@@ -381,9 +341,17 @@ sub uses {
 }
 
 
+=head1 NOTES
+
+This module is designed to make it simple, easy and quite fast to code your
+design in perl.  If for any reason you feel that it doesn't achieve these goals
+then please let me know.  I am here to help.  All constructive criticisms are
+also welcomed.
+
+
 =head1 AUTHOR
 
-Kevin Treleaven <kevin AT treleaven DOT net>
+Kevin Treleaven <kevin I<AT> treleaven I<DOT> net>
 
 =cut
 
